aboutsummaryrefslogtreecommitdiffstats
path: root/gtk
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2001-09-26 20:02:36 +0000
committerGuy Harris <guy@alum.mit.edu>2001-09-26 20:02:36 +0000
commitc2d19c1cebadb7d29d871e4af427f800aff855d5 (patch)
tree8671a4460557d9b7f7fb8e8ce31ce52651520cc7 /gtk
parent4325d41fbd225074201140234c7c4b2484f4a0b2 (diff)
Make the message popped up if you try to do a capture on a Win32 machine
when wpcap.dll couldn't be loaded more detailed, in the hopes that it'll reduce the chances that somebody will see that message and not know what to do. Also, mention the Wiretapped.net mirror of the WinPcap site, as the WinPcap site is all-too-often down due to networking glitches. svn path=/trunk/; revision=3955
Diffstat (limited to 'gtk')
-rw-r--r--gtk/capture_dlg.c15
1 files changed, 9 insertions, 6 deletions
diff --git a/gtk/capture_dlg.c b/gtk/capture_dlg.c
index c7e01acdd7..75667d8478 100644
--- a/gtk/capture_dlg.c
+++ b/gtk/capture_dlg.c
@@ -1,12 +1,11 @@
/* capture_dlg.c
* Routines for packet capture windows
*
- * $Id: capture_dlg.c,v 1.43 2001/05/31 08:36:45 guy Exp $
+ * $Id: capture_dlg.c,v 1.44 2001/09/26 20:02:36 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@zing.org>
* Copyright 1998 Gerald Combs
- *
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
@@ -142,9 +141,13 @@ capture_prep_cb(GtkWidget *w, gpointer d)
/* Is WPcap loaded? */
if (!has_wpcap) {
simple_dialog(ESD_TYPE_CRIT, NULL,
- "Unable to load WinPcap (wpcap.dll). Capturing not enabled.\n"
- "See http://netgroup-serv.polito.it/winpcap/ for\n"
- "more details on WinPcap.");
+ "Unable to load WinPcap (wpcap.dll); Ethereal will not be able\n"
+ "to capture packets.\n\n"
+ "In order to capture packets, WinPcap must be installed; see\n"
+ "http://netgroup-serv.polito.it/winpcap/, or the mirror at\n"
+ "http://www.wiretapped.net/security/packet-capture/winpcap/default.htm,\n"
+ "for a downloadable version of WinPcap and for instructions\n"
+ "on how to install WinPcap.");
return;
}
#endif
@@ -1,12 +1,11 @@
*
* Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
* Copyright 1998 Gerald Combs